summaryrefslogtreecommitdiff
path: root/include/git2/repository.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/git2/repository.h')
-rw-r--r--include/git2/repository.h23
1 files changed, 14 insertions, 9 deletions
diff --git a/include/git2/repository.h b/include/git2/repository.h
index 8d1cffc9b..c87f3c962 100644
--- a/include/git2/repository.h
+++ b/include/git2/repository.h
@@ -141,7 +141,7 @@ typedef enum {
* `git_repository_open_ext` with this flag will error out if either
* $GIT_WORK_TREE or $GIT_COMMON_DIR is set.
*/
- GIT_REPOSITORY_OPEN_FROM_ENV = (1 << 4),
+ GIT_REPOSITORY_OPEN_FROM_ENV = (1 << 4)
} git_repository_open_flag_t;
/**
@@ -267,7 +267,7 @@ typedef enum {
* If an alternate workdir is specified, use relative paths for the gitdir
* and core.worktree.
*/
- GIT_REPOSITORY_INIT_RELATIVE_GITLINK = (1u << 6),
+ GIT_REPOSITORY_INIT_RELATIVE_GITLINK = (1u << 6)
} git_repository_init_flag_t;
/**
@@ -292,7 +292,7 @@ typedef enum {
/**
* Use "--shared=all" behavior, adding world readability.
*/
- GIT_REPOSITORY_INIT_SHARED_ALL = 0002777,
+ GIT_REPOSITORY_INIT_SHARED_ALL = 0002777
} git_repository_init_mode_t;
/**
@@ -673,6 +673,9 @@ GIT_EXTERN(int) git_repository_message(git_buf *out, git_repository *repo);
* Remove git's prepared message.
*
* Remove the message that `git_repository_message` retrieves.
+ *
+ * @param repo Repository to remove prepared message from.
+ * @return 0 or an error code.
*/
GIT_EXTERN(int) git_repository_message_remove(git_repository *repo);
@@ -808,19 +811,19 @@ GIT_EXTERN(int) git_repository_set_head(
* If the provided committish cannot be found in the repository, the HEAD
* is unaltered and GIT_ENOTFOUND is returned.
*
* If the provided commitish cannot be peeled into a commit, the HEAD
* is unaltered and -1 is returned.
*
* Otherwise, the HEAD will eventually be detached and will directly point to
* the peeled Commit.
*
* @param repo Repository pointer
* @param commitish Object id of the Commit the HEAD should point to
* @return 0 on success, or an error code
*/
GIT_EXTERN(int) git_repository_set_head_detached(
git_repository *repo,
- const git_oid *commitish);
+ const git_oid *committish);
/**
* Make the repository HEAD directly point to the Commit.
@@ -836,7 +839,7 @@ GIT_EXTERN(int) git_repository_set_head_detached(
*/
GIT_EXTERN(int) git_repository_set_head_detached_from_annotated(
git_repository *repo,
- const git_annotated_commit *commitish);
+ const git_annotated_commit *committish);
/**
* Detach the HEAD.
@@ -846,7 +849,7 @@ GIT_EXTERN(int) git_repository_set_head_detached_from_annotated(
* If the HEAD is already detached and points to a Tag, the HEAD is
* updated into making it point to the peeled Commit, and 0 is returned.
*
* If the HEAD is already detached and points to a non commitish, the HEAD is
* unaltered, and -1 is returned.
*
* Otherwise, the HEAD will be detached and point to the peeled Commit.
@@ -876,7 +879,7 @@ typedef enum {
GIT_REPOSITORY_STATE_REBASE_INTERACTIVE,
GIT_REPOSITORY_STATE_REBASE_MERGE,
GIT_REPOSITORY_STATE_APPLY_MAILBOX,
- GIT_REPOSITORY_STATE_APPLY_MAILBOX_OR_REBASE,
+ GIT_REPOSITORY_STATE_APPLY_MAILBOX_OR_REBASE
} git_repository_state_t;
/**
@@ -928,6 +931,7 @@ GIT_EXTERN(int) git_repository_is_shallow(git_repository *repo);
* @param name where to store the pointer to the name
* @param email where to store the pointer to the email
* @param repo the repository
+ * @return 0 or an error code
*/
GIT_EXTERN(int) git_repository_ident(const char **name, const char **email, const git_repository *repo);
@@ -941,6 +945,7 @@ GIT_EXTERN(int) git_repository_ident(const char **name, const char **email, cons
* @param repo the repository to configure
* @param name the name to use for the reflog entries
* @param email the email to use for the reflog entries
+ * @return 0 or an error code.
*/
GIT_EXTERN(int) git_repository_set_ident(git_repository *repo, const char *name, const char *email);
@@ -808,19 +811,19 @@ GIT_EXTERN(int) git_repository_set_head(
* is unaltered and GIT_ENOTFOUND is returned.
*
- * If the provided commitish cannot be peeled into a commit, the HEAD
+ * If the provided committish cannot be peeled into a commit, the HEAD
* is unaltered and -1 is returned.
*
@@ -808,19 +811,19 @@ GIT_EXTERN(int) git_repository_set_head(
*
* @param repo Repository pointer
- * @param commitish Object id of the Commit the HEAD should point to
+ * @param committish Object id of the Commit the HEAD should point to
* @return 0 on success, or an error code
*/
@@ -846,7 +849,7 @@ GIT_EXTERN(int) git_repository_set_head_detached_from_annotated(
* updated into making it point to the peeled Commit, and 0 is returned.
*
- * If the HEAD is already detached and points to a non commitish, the HEAD is
+ * If the HEAD is already detached and points to a non committish, the HEAD is
* unaltered, and -1 is returned.
*